`xoutil.validators.identifiers`:mod: -- Simple identifiers validators
=====================================================================

.. automodule:: xoutil.validators.identifiers
   :members:
